@@ -9,6 +9,20 @@ coef(po,c("x1.0","x2.0","alpha.1","alpha.4")) <- c(0,0,0.1,0.2)
 po <- simulate(po)
 guess <- p.truth <- coef(po)
 
+m1 <- nlf(
+          object=po,
+          start=guess,
+          lags=c(1,2),
+          nconverge=100,
+          nasymp=1000,
+          trace=1,
+          verbose=TRUE,
+          eval.only=TRUE,
+          lql.frac = 0.025
+          )
+
+print(m1)
+
 m1 <- nlf(
           object=po,
           start=guess,
